Result on Huber benchmark

# Benchopt

Dataset:
Objective:
Objective metrics
Chart type
Scale
X-axis
Quantiles
Save as view

## Result on Huber benchmark

CPU : 4
RAM (GB) : 31
CUDA : NVIDIA GeForce RTX 4090: cuda_12.2
Download :
Configs
HTML
Data
Select a tab
Solvers (Click on a solver to hide it or double click to hide all the others)

### System information

- CPU: 4
- RAM (GB): 31
- CUDA: NVIDIA GeForce RTX 4090: cuda_12.2
- platform: Linux6.2.0-34-generic-x86_64
- processor: 13th Gen Intel(R) Core(TM) i9-13900K
- numpy: 1.26.0
- scipy: 1.11.3